﻿using System;
using System.Configuration;
using System.IO;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.WebForms;

namespace WebApplication1
{
    public partial class Index : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                // source
                string rootPath = Path.Combine(MapPath("~"), ConfigurationManager.AppSettings["RootDirectory"]);
                var shapeFileSource = new ShapeFileFeatureSource(Path.Combine(rootPath, "swineflu.shp"));

                // set Map arguments at first, you must be set the ZoomLevelSet to same with ThinkGeoCloudMapsOverlay
                Map1.MapUnit = GeographyUnit.Meter;
                Map1.ZoomLevelSet = ThinkGeoCloudMapsOverlay.GetZoomLevelSet();
                Map1.CurrentExtent = new RectangleShape(-16697924, 9349764, -10018754, 1804723);

                // ThinkGeoCloudMapsOverlay
                var cloudMapsOverlay = new ThinkGeoCloudMapsOverlay();
                cloudMapsOverlay.WrapDateline = WrapDatelineMode.WrapDateline;
                Map1.CustomOverlays.Add(cloudMapsOverlay);

                // heatOverlay
                var heatOverlay = new LayerOverlay("Heat");
                Map1.CustomOverlays.Add(heatOverlay);

                // heatLayer
                var heatLayer = new HeatLayer(shapeFileSource)
                {
                    HeatStyle = new HeatStyle()
                    {
                        PointRadius = 100,
                        PointRadiusUnit = DistanceUnit.Kilometer,
                        Alpha = 180,
                        PointIntensity = 10,
                        IntensityColumnName = "CONFIRMED",
                        IntensityRangeStart = 0,
                        IntensityRangeEnd = 638
                    }
                };
                heatOverlay.Layers.Add("Heat", heatLayer);
            }
        }
    }
}